""" the collections of mapper functions.

"""
from extjs import TabPanel


def map_default(fields):
    """Map a list of field in the ``Ext.form.formPanel``.

    Args:
        fields (list): database field names

    Returns:
        list:
            the input list

    """
    return fields


def map_tabpanel(fieldsets):
    """Map a list of ``FieldSets`` in the ``Ext.TabPanel``.

        * A tab is associated to each fieldset.
        * the name of the tab is the name of the fieldset.

    Args:
        fieldsets (list): a series of :class:`.FieldSet`

    Returns:
        list:
            the :class:`.TapPanel` encapsulated in a list.

    """

    tabpanel = TabPanel(activeTab=0,
                        enableTabScroll=True,
                        layout='fit',
                        defaults={'layout': 'fit'})

    for fieldset in fieldsets:

        fieldset['border'] = False

        title = fieldset['title']
        del fieldset['title']

        tab = {'border': False,
               'collapsible': False,
               'frame': True,
               'items': fieldset,
               'defaults': {'padding': 10},
               'title': title}

        tabpanel.append_items(tab)

    return [tabpanel]
