""" the viewport modifier.

"""

from gluon.storage import Storage
from modifier import Modifier
from navtree import Node


MSG_INVALID_NODE = 'Node object is not an instance of NodeBase class.'

MODIFIER_VIEWPORTS = 'modifier_viewports'


class ViewportModifier(Modifier):
    """Modifier to customize the viewport widget of the application.

    """

    def __init__(self):
        """Initialize the viewport modifier associated to the application.

        The persistent data structure of the viewport modifier can be access
        outside the class::

            p = PluginManager('dbui')
            modifier = p.dbui['modifier_viewports']

        or internally via the attribute ``data``.

        The keys of the ``data`` structure are:

            * ``default`` (list) list of node defining the path of the node
               which will be opened at start up. Each node is identify its
              ``text`` string.

            * ``extjs`` (dict) Ext JS configuration options for the
              viewport widget.

            * ``nodes`` (list) list of :class:`.Node`
            defining the navigation tree

        """
        Modifier.__init__(self, MODIFIER_VIEWPORTS)

        if 'default' not in self.data:
            self.data.default = None

        if 'nodes' not in self.data:
            self.data.nodes = []


    def add_node(self, *args):
        """Add a list of :class:`.Node`
        to the navigation tree.

        Args:
            args (list): list of :class:`.Node`

        .. note::
            Elements of the list equal to ``None`` are ignored.
            This feature is useful when the list of nodes depend on user role.

        :raise ViewportModifierException:
            at least one element of the list
            is not a ``Node`` or ``None``.

        """
        li = []
        for el in args:

            if isinstance(el, Node):
                li.append(el)

            elif el == None:
                continue

            else:
                raise ViewportModifierException(MSG_INVALID_NODE)

        self.data.nodes.extend(li)


    def default_node(self, *args):
        """Defined the node which will be opened at start up.

        Args:
            args (list): nodes identified by their ``text`` string.

        """
        self.data.default = args


class ViewportModifierException(BaseException): pass
